<?php
require("Hail/MailFolderItem.class.php");
require("Hail/MailFolder.class.php");
require("Hail/HTTPMail.class.php");

/**
 * The IMP_Fetchmail_hotmail driver implements the Hotmail_Fetchmail class for use
 * with Hotmail Services.
 *
 * $Horde: imp/lib/Fetchmail/hotmail.php,v 1.0 2004/05/22 19:00:0 vma Exp 
 *
 * @since   IMP 4.0
 * @package IMP
 */
class IMP_Fetchmail_hotmail extends IMP_Fetchmail {
    /**
     * Returns a description of the driver.
     *
     * @see IMP_Fetchmail::description()
     */
    function description()
    {
        return _("Hotmail Service");
    }
    
    /**
     * Constructor.
     *
     * @access public
     *
     * @param array $params  The configuration parameter array.
     */
    function IMP_Fetchmail_hotmail($params)
    {
        /* Default values for a couple of parameters. */
        $defaults = array(
            'rmailbox' => 'inbox',
            'lmailbox' => 'INBOX'
        );
        $params = array_merge($defaults, $params);
	
        parent::IMP_Fetchmail($params);
    }
    
    /**
     * Returns the list of Hotmail Remote Folders.
     *
     * @access private
     *
     * @return array  The folder list.
     */
    function _getFolderList($hm)
    {
	$folders = array();
	foreach($hm->get_folders() as $f) {
	    $folders[$f->name] = $f->name;
	}
	return $folders;
    }

    /**
     * Return a list of protocols supported by this driver.
     *
     * @see IMP_Fetchmail::getProtocolList()
     */
    function getProtocolList()
    {
        return array('Hotmail'=>'Hotmail');
    }


    /**
     * Gets the mail using the data in this object.
     *
     * @see IMP_Fetchmail::getMail()
     */
    function getMail()
    {
	$numMsgs = 0;
	//Create object
	$hm = new HTTPMail($this->_params['username'], $this->_params['password']);
	if ($hm->login()) { //Login to Hotmail
	    $folder_list = $this->_getFolderList($hm);
	    
	    foreach ($folder_list as $folder) { // Check right folder
		if ($folder == $this->_params['rmailbox']) {
		    $numMsgs = 0;
		    
		    $urlmsg = array();
		    //Get Message List
		    foreach($hm->get_folder_items($folder) as $item) {
			if ($this->_params['onlynew']) {
			    if ($item->new)
			      $urlmsg[] = $item->url;
			} else
			  $urlmsg[] = $item->url;
		    }
		    
		    //Get Messages
		    foreach ($urlmsg as $url) {
			$mail_source = $hm->get_email($url);
			/* Append to the server. */
			if ($this->_addMessage($mail_source)) {
			    $numMsgs++;
			    
			    /* Remove the mail if 'del' is set. */
			    if ($this->_params['del']) {
				$hm->delete_mail($url);
			    }
			    
			    /* Mark message seen if 'markseen' is set. */
			    if ($this->_params['markseen']) {
				$hm->update_read($url, 1);
			    }
			}
		    }
		}
	    }
	} else { 
	    return PEAR::raiseError(_("Connection to server failed"));
	}
        return $numMsgs;
    }
}
